@@ -24,9 +24,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-extern "C" {
-	#include <R.h>
-}
+/* extern "C" { */
+#include <R.h>
+/* } */
 
 #include "matrix.h"
 
